==> static_postgres_orm-0.0.2-dev.tar.gz: lib/src/domain/orm_domain_types.dart <==
import 'dart:convert';
import 'package:dartz/dartz.dart';
import 'package:data_db/data_db.dart';

String getJsonValue(String name, dynamic value) {
  return '${jsonEncode(name)}: ${jsonEncode(value)}';
}

String mapToJson(Map<String, dynamic> object) {
  var jsonString = '';
  object.forEach((key, value) {
    if (value != null) {
      jsonString += ', ${jsonEncode(key)}: ${jsonEncode(value)}';
    }
  });

  return '{${jsonString.replaceFirst(', ', '')}}';
}

abstract class SqlResult {
  final bool result;
  final String className;
  String methodName;
  final String? sqlCommand;

  SqlResult(this.result, this.className, this.methodName, {this.sqlCommand});

  Map<String, dynamic> getJsonFields() {
    return {
      'result': result,
      'className': className,
      'methodName': methodName,
      'sqlCommand': sqlCommand
    };
  }

  String toJson() {
    return mapToJson(getJsonFields());
  }
}

class ExecuteSuccesSqlResult extends SqlResult {
  final int rowsAffected;

  ExecuteSuccesSqlResult(String className, String methodName, this.rowsAffected)
      : super(true, className, methodName);

  @override
  Map<String, dynamic> getJsonFields() {
    return super.getJsonFields()..addAll({'rowsAffected': rowsAffected});
  }
}

class SelectSuccesSqlResult extends SqlResult {
  final int rowsSelected;
  late final Dataset dataset;
  final List<List<dynamic>> content;

  SelectSuccesSqlResult(
      String className, String methodName, this.rowsSelected, this.content)
      : super(true, className, methodName);

  @override
  Map<String, dynamic> getJsonFields() {
    return super.getJsonFields()..addAll({'rowsSelected': rowsSelected});
  }
}

class ErrorSqlResult extends SqlResult {
  final String? errorCode;
  final List<String> errorMessage;

  ErrorSqlResult(String className, String methodName, String? sqlCommand,
      this.errorMessage,
      {this.errorCode})
      : super(false, className, methodName, sqlCommand: sqlCommand);

  @override
  Map<String, dynamic> getJsonFields() {
    return super.getJsonFields()
      ..addAll({'errorCode': errorCode, 'errorMessage': errorMessage});
  }
}

abstract class SqlConnection {
  Future<Either<ErrorSqlResult, ExecuteSuccesSqlResult>> executeCommand(
      String methodName, String sql);
  Future<Either<ErrorSqlResult, SelectSuccesSqlResult>> openQuery(
      String methodName, String sql);
}

==> static_postgres_orm-0.0.4-dev.tar.gz: lib/src/domain/orm_domain_types.dart <==
import 'dart:convert';
import 'package:dartz/dartz.dart';
import 'package:data_db/data_db.dart';

String getJsonValue(String name, dynamic value) {
  return '${jsonEncode(name)}: ${jsonEncode(value)}';
}

String mapToJson(Map<String, dynamic> object) {
  var jsonString = '';
  object.forEach((key, value) {
    if (value != null) {
      jsonString += ', ${jsonEncode(key)}: ${jsonEncode(value)}';
    }
  });

  return '{${jsonString.replaceFirst(', ', '')}}';
}

abstract class SqlResult {
  final bool result;
  final String className;
  String methodName;
  final String? sqlCommand;

  SqlResult(this.result, this.className, this.methodName, {this.sqlCommand});

  Map<String, dynamic> getJsonFields() {
    return {
      'result': result,
      'className': className,
      'methodName': methodName,
      'sqlCommand': sqlCommand
    };
  }

  String toJson() {
    return mapToJson(getJsonFields());
  }
}

class ExecuteSuccesSqlResult extends SqlResult {
  final int rowsAffected;
  late Dataset? dataset;

  ExecuteSuccesSqlResult(String className, String methodName, this.rowsAffected, [this.dataset])
      : super(true, className, methodName);

  @override
  Map<String, dynamic> getJsonFields() {
    return super.getJsonFields()..addAll({'rowsAffected': rowsAffected});
  }
}

class SelectSuccesSqlResult extends SqlResult {
  final int rowsSelected;
  late final Dataset dataset;
  final List<List<dynamic>> content;

  SelectSuccesSqlResult(
      String className, String methodName, this.rowsSelected, this.content)
      : super(true, className, methodName);

  @override
  Map<String, dynamic> getJsonFields() {
    return super.getJsonFields()..addAll({'rowsSelected': rowsSelected});
  }
}

class ErrorSqlResult extends SqlResult {
  final String? errorCode;
  final List<String> errorMessage;

  ErrorSqlResult(String className, String methodName, String? sqlCommand,
      this.errorMessage,
      {this.errorCode})
      : super(false, className, methodName, sqlCommand: sqlCommand);

  @override
  Map<String, dynamic> getJsonFields() {
    return super.getJsonFields()
      ..addAll({'errorCode': errorCode, 'errorMessage': errorMessage});
  }
}

abstract class SqlConnection {
  Future<Either<ErrorSqlResult, ExecuteSuccesSqlResult>> executeCommand(
      String methodName, String sql);
  Future<Either<ErrorSqlResult, SelectSuccesSqlResult>> openQuery(
      String methodName, String sql);
}

extension ProtoSelect on Either<ErrorSqlResult, Dataset> {
  Map<String, Object> toProto3Json() {
    var proto = <String, Object>{};
    var result = false;
    var rowsSelected = 0;
    var totalRowsCount = 0;
    var errorMessage = <String>[];
    var data = <Map<String, Map<String, dynamic>>>[];

    fold((l) {
      errorMessage.add(l.toJson());
    }, (dataset) {
      if (dataset.isNotempty) {
        data = dataset.toProto3Json();
        rowsSelected = dataset.count;
        dataset.first();
        dataset.fieldByName('qqqtttddd_rrreeeggg').map(
          (a) => a.tryGetValue((value) => totalRowsCount = value)
        );
        result = true;
      }
    });

    proto.addAll({
      'result': result,
      'rowsSelected': rowsSelected,
      'totalRowsCount': totalRowsCount,
    });

    if (data.isNotEmpty) {
      proto.addAll({'data': data});
    }
    if (errorMessage.isNotEmpty) {
      proto.addAll({'errorMessage': errorMessage});
    }

    return proto;
  }
}
